#ifndef PARTITION_H
#define PARTITION_H

#include "diskio.h"
#include "ps2part.h"

typedef struct partbuf {
    struct partbuf *next, *prev;
    struct ps2_partition *part;
    sector_t sect;
    int nsect;
    int modified;
} PARTBUF;

#define EP_OK		0
#define EP_READ		-1	/* disk read error */
#define EP_WRITE	-2	/* disk write error */
#define EP_NOMEM	-3	/* no memory error */
#define EP_BADMBR	-4	/* bad MBR format */
#define EP_BADPART	-5	/* bad partition format */
#define EP_NOPART	-6	/* no such partition */
#define EP_ILLEGAL	-7	/* illegal parameter */
#define EP_FULL		-8	/* disk full */
#define EP_EXIST	-9	/* partition id already exists */

#define get_nsect(dev, size)	((size) / (dev)->sector_size > 0 ? \
				 (size) / (dev)->sector_size : 1)

void free_partition(PARTBUF *pbuf);
PARTBUF *find_partition(PARTBUF *phead, char *id);
int next_avail_partition(PARTBUF *phead);
int create_partition(DISKDEV *dev, PARTBUF *phead, char *id, sector_t size,
		     int fstype, char *name);
int remove_partition(DISKDEV *dev, PARTBUF *phead, char *id);

sector_t getfree_partition(DISKDEV *dev, PARTBUF *phead);
sector_t getsize_partition(DISKDEV *dev, PARTBUF *pbuf);

int format_partition(DISKDEV *dev, PARTBUF **pphead);
int read_partition(DISKDEV *dev, PARTBUF **pphead);
int write_partition(DISKDEV *dev, PARTBUF *phead);

#endif /* PARTITION_H */
